@@ -19,12 +19,13 @@ from ._helpers import (
     InitStrategyInfo,
     construct_problem_instance,
     get_initialization_strategies,
+    get_size_range,
     problem_has_constraints,
 )
 
 
 # =================================================================================================
-#  Benchmark file
+#  Benchmark function
 # =================================================================================================
 def benchmark_initialization_strategies(problem_name: str, markdown: bool, file: bool = False, speed: float = 0.0):
     """
@@ -35,12 +36,11 @@ def benchmark_initialization_strategies(problem_name: str, markdown: bool, file:
     :param file: If True, redirects output to a file instead of console.
     :param speed: Speed factor to adjust the benchmark duration (0.0 = full, 1.0 = fastest).
     """
-    print(f"Benchmarking initialization strategies on problem: {problem_name}")
 
     # --- prep --------------------------------------------
     diversity_metric = DiversityMetric.geomean_separation()
-    size_range = list(range(1, 1 + int(20 - 19 * speed)))  # [1,20] for speed=0.0 to [1,1] for speed=1.0
-    n_seeds = int(32 - speed * 31)  # from 1 (speed=1.0) to 32 (speed=0.0)
+    size_range = get_size_range(speed)
+    n_seeds = int(10 - speed * 9)  # from 1 (speed=1.0) to 10 (speed=0.0)
     has_constraints = problem_has_constraints(problem_name, [min(size_range), max(size_range)])
     init_strategies: list[InitStrategyInfo] = get_initialization_strategies(has_constraints)
 
@@ -50,10 +50,16 @@ def benchmark_initialization_strategies(problem_name: str, markdown: bool, file:
     diversity_scores: dict[int, dict[str, NumberWithUncertainty]] = defaultdict(dict)
     constraint_scores: dict[int, dict[str, NumberWithUncertainty]] = defaultdict(dict)
 
-    for size in tqdm(size_range, leave=False):
+    size_exp = 2.0  # exponent with which size influences time spent
+    pbar = tqdm(
+        desc=f"problem {problem_name} - Initialization strategies".ljust(40),
+        total=sum([round(s**size_exp) for s in size_range]) * len(init_strategies) * n_seeds,
+        leave=file,
+    )
+
+    for size in size_range:
         # Create problem instance
         problem = construct_problem_instance(problem_name, size, diversity_metric)
-
         # go over all initialization strategies
         for strat_info in init_strategies:
             # initialize lists for this (size, strategy)
@@ -81,6 +87,10 @@ def benchmark_initialization_strategies(problem_name: str, markdown: bool, file:
                 diversity_scores_lst.append(solution.score.diversity)
                 constraint_scores_lst.append(solution.score.constraints)
 
+                # Update progress bar
+                pbar.n += round(size**size_exp)
+                pbar.refresh()
+
             # Register results for this (size, strategy)
             times[size][strat_info.name] = BenchmarkResult.from_list(times_lst)
             diversity_scores[size][strat_info.name] = NumberWithUncertainty.from_list(diversity_scores_lst)
